import { Container, PLATFORM } from "aurelia-framework";
import { coerceFunctions, usePropertyTypeForBindable, usePropertyTypeForObservable } from "aurelia-typed-observable-plugin";
import { PitayaConfiguration } from "./configuration";
export function configure(frameworkConfig, callback) {
    frameworkConfig.plugin(PLATFORM.moduleName("aurelia-animator-css"))
        .plugin(PLATFORM.moduleName("aurelia-fetch-client"))
        .plugin(PLATFORM.moduleName("aurelia-typed-observable-plugin"))
        .postTask(configureAureliaTypedObservablePlusin)
        .globalResources([
        PLATFORM.moduleName("./elements/pitaya-app"),
        PLATFORM.moduleName("./elements/pitaya-view"),
    ]);
    if (callback instanceof Function) {
        const config = Container.instance.get(PitayaConfiguration);
        callback(config);
    }
}
const configureAureliaTypedObservablePlusin = function () {
    usePropertyTypeForBindable(true);
    usePropertyTypeForObservable(true);
    coerceFunctions.boolean = value => value === undefined ? value : value !== false;
    coerceFunctions.string = value => value === undefined ? value : value.toString();
    coerceFunctions.number = value => value === undefined ? value : parseFloat(value);
    coerceFunctions.Function = coerceFunctions.function;
    coerceFunctions.numberOrString = value => {
        if (value === undefined) {
            return;
        }
        const toNumber = parseFloat(value);
        return isNaN(toNumber) ? value.toString() : toNumber;
    };
};
export * from "./elements/pitaya-app";
export * from "./elements/pitaya-view";
export * from "./utility/decorators";
export * from "./utility/utils";
export * from "./configuration";

//# sourceMappingURL=index.js.map
